changeset 23262:dca9e6b931d3 v8.2.2177

patch 8.2.2177: pattern "^" does not match if first character is combining Commit: https://github.com/vim/vim/commit/ef2dff52de52c17fe1bd7c06cbb32d8955901f5a Author: Bram Moolenaar <Bram@vim.org> Date: Mon Dec 21 14:54:32 2020 +0100 patch 8.2.2177: pattern "^" does not match if first character is combining Problem: Pattern "^" does not match if the first character in the line is combining. (Rene Kita) Solution: Do accept a match at the start of the line. (closes #6963)
author Bram Moolenaar <Bram@vim.org>
date Mon, 21 Dec 2020 15:00:04 +0100
parents cda94e178e18
children fa5052e3f93a
files src/regexp_nfa.c src/testdir/test_regexp_utf8.vim src/version.c
diffstat 3 files changed, 18 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/testdir/test_regexp_utf8.vim
+++ b/src/testdir/test_regexp_utf8.vim
@@ -501,4 +501,15 @@ func Test_search_with_end_offset()
   close!
 endfunc
 
+" Check that "^" matches even when the line starts with a combining char
+func Test_match_start_of_line_combining()
+  new
+  call setline(1, ['', "\u05ae", ''])
+  exe "normal gg/^\<CR>"
+  call assert_equal(2, getcurpos()[1])
+  bwipe!
+endfunc
+
+
+
 " vim: shiftwidth=2 sts=2 expandtab
--- a/src/version.c
+++ b/src/version.c
@@ -751,6 +751,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    2177,
+/**/
     2176,
 /**/
     2175,
--- a/src/regexp_nfa.c
+++ b/src/regexp_nfa.c
@@ -5754,9 +5754,11 @@ nfa_regmatch(
 	    {
 	    case NFA_MATCH:
 	      {
-		// If the match ends before a composing characters and
-		// rex.reg_icombine is not set, that is not really a match.
-		if (enc_utf8 && !rex.reg_icombine && utf_iscomposing(curc))
+		// If the match is not at the start of the line, ends before a
+		// composing characters and rex.reg_icombine is not set, that
+		// is not really a match.
+		if (enc_utf8 && !rex.reg_icombine
+			     && rex.input != rex.line && utf_iscomposing(curc))
 		    break;
 
 		nfa_match = TRUE;